@@ -40,6 +40,7 @@ pub struct Options {
     pub show_warnings: bool,
     pub edition: Edition,
     pub debugger: Debugger,
+    pub shell_interpolate: bool,
 }
 
 impl Default for Options {
@@ -94,6 +95,7 @@ impl Default for Options {
             show_warnings: false,
             edition: Edition::E2021,
             debugger: Debugger::LLDB,
+            shell_interpolate: true,
         }
     }
 }
@@ -136,7 +138,7 @@ impl Options {
         };
 
         // Ignore directory exists error
-        let _ = std::fs::create_dir(&config_dir);
+        let _ = std::fs::create_dir_all(&config_dir);
         let config_path = config_dir.join("config");
 
         Some(config_path)
