@@ -305,11 +305,17 @@ impl IRust {
         let buffer = &buffer[2..];
 
         let mut cmd = buffer.split_whitespace();
-        let output = stdout_and_stderr(
+        let output = stdout_and_stderr(if cfg!(windows) {
+            std::process::Command::new("cmd")
+                .arg("/C")
+                .arg(cmd.next().unwrap_or_default())
+                .args(&cmd.collect::<Vec<&str>>())
+                .output()?
+        } else {
             std::process::Command::new(cmd.next().unwrap_or_default())
                 .args(&cmd.collect::<Vec<&str>>())
-                .output()?,
-        )
+                .output()?
+        })
         .trim()
         .to_owned();
 
@@ -372,7 +378,7 @@ impl IRust {
             let mut insert_flag = true;
 
             if self.options.check_statements {
-                self.while_compiling_hook();
+                self.before_compiling_hook();
                 let check_result = self.repl.eval_check(buffer.clone());
                 self.after_compiling_hook();
                 if let Some(mut e) =
@@ -393,7 +399,7 @@ impl IRust {
         } else {
             let mut outputs = PrintQueue::default();
 
-            self.while_compiling_hook();
+            self.before_compiling_hook();
             let result = self.repl.eval_with_configuration(EvalConfig {
                 input: buffer,
                 interactive_function: Some(ctrlc_cancel),
@@ -831,18 +837,36 @@ impl IRust {
                         shell_expr.push(s);
                     }
                     let mut shell_expr = shell_expr.split_whitespace();
-                    let shell_res = process::Command::new(shell_expr.next()?)
-                        .args(shell_expr.collect::<Vec<_>>())
-                        .output();
-                    let mut shell_res = match shell_res {
+                    let shell_res = if cfg!(windows) {
+                        process::Command::new("cmd")
+                            .arg("/C")
+                            .arg(shell_expr.next()?)
+                            .args(shell_expr.collect::<Vec<_>>())
+                            .output()
+                    } else {
+                        process::Command::new(shell_expr.next()?)
+                            .args(shell_expr.collect::<Vec<_>>())
+                            .output()
+                    };
+                    let shell_res = match shell_res {
                         Ok(res) => stdout_and_stderr(res),
                         Err(e) => {
                             maybe_error = Some(e);
                             break None;
                         }
                     };
-                    shell_res.insert(0, '"');
-                    shell_res.push('"');
+
+                    struct F<'a>(&'a [u8]);
+                    impl std::fmt::Display for F<'_> {
+                        fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
+                            write!(f, "String::from_utf8_lossy(&[")?;
+                            for b in self.0.iter() {
+                                write!(f, "{},", b)?;
+                            }
+                            write!(f, "]).to_string()")
+                        }
+                    }
+                    let shell_res = format!("{}", F(shell_res.as_bytes()));
                     res.push_str(&shell_res);
                 } else {
                     res.push(c);
